@@ -19,16 +19,17 @@
  ***************************************************************************/
 
 // QT Includes
-#include <qmap.h>
-#include <qdict.h>
+#include <QMap>
+#include <QList>
+#include <QHash>
 
 // KDE Includes
-#include <kapplication.h>
 #include <kdebug.h>
 #include <kgenericfactory.h>
 #include <kmessagebox.h>
-#include <ksimpleconfig.h>
+#include <kconfig.h>
 #include <kstandarddirs.h>
+#include <ktoolinvocation.h>
 
 // Kopete Includes
 #include "kopeteaccountmanager.h"
@@ -40,21 +41,21 @@
 #include "wpaccount.h"
 #include "wpcontact.h"
 
-class KPopupMenu;
+class KMenu;
 
 WPProtocol *WPProtocol::sProtocol = 0;
 
-typedef KGenericFactory<WPProtocol> WPProtocolFactory;
-K_EXPORT_COMPONENT_FACTORY( kopete_wp, WPProtocolFactory( "kopete_wp" )  )
+K_PLUGIN_FACTORY( WPProtocolFactory, registerPlugin<WPProtocol>(); )
+K_EXPORT_PLUGIN( WPProtocolFactory( "kopete_wp" ) )
 
 // WP Protocol
-WPProtocol::WPProtocol( QObject *parent, const char *name, const QStringList & /* args */ )
-: Kopete::Protocol( WPProtocolFactory::instance(), parent, name ),
-	WPOnline(  Kopete::OnlineStatus::Online,  25, this, 0,  QString::null, i18n("Online"),  i18n("Online")),
-	WPAway(    Kopete::OnlineStatus::Away,    20, this, 1,  "wp_away",     i18n("Away"),    i18n("Away")),
-	WPOffline( Kopete::OnlineStatus::Offline, 0,  this, 2,  QString::null, i18n("Offline"), i18n("Offline"))
+WPProtocol::WPProtocol( QObject *parent, const QVariantList & /* args */ )
+: Kopete::Protocol( WPProtocolFactory::componentData(), parent ),
+	WPOnline(  Kopete::OnlineStatus::Online,  25, this, 0,  QStringList(), i18n("Online"),  i18n("Online")),
+	WPAway(    Kopete::OnlineStatus::Away,    20, this, 1,  QStringList(QString::fromLatin1("wp_away")),     i18n("Away"),    i18n("Away")),
+	WPOffline( Kopete::OnlineStatus::Offline, 0,  this, 2,  QStringList(), i18n("Offline"), i18n("Offline"))
 {
-//	kdDebug(14170) << "WPProtocol::WPProtocol()" << endl;
+//	kDebug(14170) << "WPProtocol::WPProtocol()";
 
 	sProtocol = this;
 
@@ -74,14 +75,14 @@ WPProtocol::WPProtocol( QObject *parent, const char *name, const QStringList & /
 // Destructor
 WPProtocol::~WPProtocol()
 {
-//	kdDebug(14170) <<  "WPProtocol::~WPProtocol()" << endl;
+//	kDebug(14170) <<  "WPProtocol::~WPProtocol()";
 
 	sProtocol = 0;
 }
 
 AddContactPage *WPProtocol::createAddContactWidget(QWidget *parent, Kopete::Account *theAccount)
 {
-//	kdDebug(14170) << "WPProtocol::createAddContactWidget(<parent>, " << theAccount << ")" << endl;
+//	kDebug(14170) << "WPProtocol::createAddContactWidget(<parent>, " << theAccount << ")";
 
 	return new WPAddContact(parent, dynamic_cast<WPAccount *>(theAccount));
 }
@@ -95,17 +96,17 @@ Kopete::Contact *WPProtocol::deserializeContact( Kopete::MetaContact *metaContac
 
 	WPAccount *theAccount = static_cast<WPAccount *>(Kopete::AccountManager::self()->findAccount(protocol()->pluginId(), accountId));
 	if(!theAccount)	{
-		kdDebug(14170) <<  "Account " << accountId << " not found" << endl;
+		kDebug(14170) <<  "Account " << accountId << " not found";
 		return 0;
 	}
 
-	if(theAccount->contacts()[contactId]) {
-		kdDebug(14170) << "User " << contactId << " already in contacts map" << endl;
+	if(theAccount->contacts().value(contactId)) {
+		kDebug(14170) << "User " << contactId << " already in contacts map";
 		return 0;
 	}
 
 	theAccount->addContact(contactId, metaContact, Kopete::Account::DontChangeKABC);
-	return theAccount->contacts()[contactId];
+	return theAccount->contacts().value(contactId);
 }
 
 KopeteEditAccountWidget *WPProtocol::createEditAccountWidget(Kopete::Account *account, QWidget *parent)
@@ -120,7 +121,7 @@ Kopete::Account *WPProtocol::createNewAccount(const QString &accountId)
 
 void WPProtocol::settingsChanged()
 {
-	kdDebug(14170) <<  "WPProtocol::slotSettingsChanged()" << endl;
+	kDebug(14170) <<  "WPProtocol::slotSettingsChanged()";
 
 	readConfig();
 	popupClient->settingsChanged(smbClientBin, groupCheckFreq);
@@ -128,20 +129,20 @@ void WPProtocol::settingsChanged()
 
 void WPProtocol::readConfig()
 {
-	KGlobal::config()->setGroup("WinPopup");
-	smbClientBin = KGlobal::config()->readEntry("SmbcPath", "/usr/bin/smbclient");
-	groupCheckFreq = KGlobal::config()->readNumEntry("HostCheckFreq", 60);
+	KConfigGroup group = KGlobal::config()->group("WinPopup");
+	smbClientBin = group.readEntry("SmbcPath", "/usr/bin/smbclient");
+	groupCheckFreq = group.readEntry("HostCheckFreq", 60);
 }
 
 void WPProtocol::installSamba()
 {
-//	kdDebug(14170) <<  "WPProtocol::installSamba()" endl;
+//	kDebug(14170) <<  "WPProtocol::installSamba()" endl;
 
 	QStringList args;
-	args += KStandardDirs::findExe("winpopup-install.sh");
-	args += KStandardDirs::findExe("winpopup-send.sh");
-	if (KApplication::kdeinitExecWait("kdesu", args) == 0)
-		KMessageBox::information(Kopete::UI::Global::mainWidget(), i18n("The Samba configuration file is modified."), i18n("Configuration Succeeded"));
+	args += KStandardDirs::findExe("winpopup-install");
+	args += KStandardDirs::findExe("winpopup-send");
+	if (KToolInvocation::kdeinitExecWait("kdesu", args) == 0)
+		KMessageBox::information(Kopete::UI::Global::mainWidget(), i18n("The Samba configuration file has been modified."), i18n("Configuration Successful"));
 	else
 		KMessageBox::error(Kopete::UI::Global::mainWidget(), i18n("Updating the Samba configuration file failed."), i18n("Configuration Failed"));
 }
@@ -152,27 +153,25 @@ void WPProtocol::installSamba()
 void WPProtocol::slotReceivedMessage(const QString &Body, const QDateTime &Time, const QString &From)
 {
 	bool foundContact = false;
-	QString accountKey = QString::null;
-	QDict<Kopete::Account> Accounts = Kopete::AccountManager::self()->accounts(protocol());
-	for (QDictIterator<Kopete::Account> it(Accounts); it.current(); ++it) {
-		QDict<Kopete::Contact> Contacts = it.current()->contacts();
-		Kopete::Contact *theContact = Contacts[From];
-		if (theContact != 0) {
+	QList<Kopete::Account*> Accounts = Kopete::AccountManager::self()->accounts(protocol());
+	Kopete::Account *theAccount = 0;
+	foreach(Kopete::Account *account, Accounts) {
+		Kopete::Contact *theContact = account->contacts().value(From);
+		if (theContact) {
 			foundContact = true;
-			dynamic_cast<WPAccount *>(it.current())->slotGotNewMessage(Body, Time, From);
+			theAccount = account;
+			dynamic_cast<WPAccount *>(account)->slotGotNewMessage(Body, Time, From);
 			break;
 		}
-
-		if (accountKey.isEmpty() && it.current()->isConnected()) accountKey = it.currentKey();
 	}
 
 	// What to do with messages with no contact?
 	// Maybe send them to the next online account? GF
 	if (!foundContact) {
-		if (!accountKey.isEmpty())
-			dynamic_cast<WPAccount *>(Accounts[accountKey])->slotGotNewMessage(Body, Time, From);
+		if (theAccount)
+			dynamic_cast<WPAccount *>(theAccount)->slotGotNewMessage(Body, Time, From);
 		else
-			kdDebug(14170) << "No contact or connected account found!" << endl;
+			kDebug(14170) << "No contact or connected account found!";
 	}
 }
 
