@@ -88,7 +88,7 @@ YahooAccount::YahooAccount(YahooProtocol *parent, const QString& accountId)
 	m_openInboxAction = new KAction( KIcon("mail-folder-inbox"), i18n( "Open Inbo&x..." ), this );
         //, "m_openInboxAction" );
 	QObject::connect(m_openInboxAction, SIGNAL( triggered(bool) ), this, SLOT( slotOpenInbox() ) );
-	m_openYABAction = new KAction( KIcon("x-office-address-book"), i18n( "Open &Addressbook..." ), this );
+	m_openYABAction = new KAction( KIcon("x-office-address-book"), i18n( "Open &Address book..." ), this );
         //, "m_openYABAction" );
 	QObject::connect(m_openYABAction, SIGNAL( triggered(bool) ), this, SLOT( slotOpenYAB() ) );
 	m_editOwnYABEntry = new KAction( KIcon("document-properties"), i18n( "&Edit my contact details..."), this );
@@ -244,6 +244,15 @@ void YahooAccount::initConnectionSignals( enum SignalConnectionType sct )
 		QObject::connect(m_session, SIGNAL(gotBuddy(const QString &, const QString &, const QString &)),
 		                 this, SLOT(slotGotBuddy(const QString &, const QString &, const QString &)));
 
+		QObject::connect(m_session, SIGNAL(buddyAddResult(const QString &, const QString &, bool)),
+				 this, SLOT(slotBuddyAddResult(const QString &, const QString &, bool)));
+
+		QObject::connect(m_session, SIGNAL(buddyRemoveResult(const QString &, const QString &, bool)),
+				 this, SLOT(slotBuddyRemoveResult(const QString &, const QString &, bool)));
+
+		QObject::connect(m_session, SIGNAL(buddyChangeGroupResult(const QString &, const QString &, bool)),
+				 this, SLOT(slotBuddyChangeGroupResult(const QString &, const QString &, bool)));
+
 		QObject::connect(m_session, SIGNAL(authorizationAccepted( const QString & )),
 		                 this, SLOT(slotAuthorizationAccepted( const QString & )) );
 
@@ -335,7 +344,7 @@ void YahooAccount::initConnectionSignals( enum SignalConnectionType sct )
 
 		QObject::connect(m_session, SIGNAL(pictureStatusNotify( const QString&, int )), SLOT(slotPictureStatusNotify( const QString&, int)));
 
-		QObject::connect(m_session, SIGNAL(pictureDownloaded(const QString&, KTemporaryFile*, int)), this, SLOT(slotGotBuddyIcon(const QString&, KTemporaryFile*, int)) );
+		QObject::connect(m_session, SIGNAL(pictureDownloaded(const QString&, const QByteArray &, int)), this, SLOT(slotGotBuddyIcon(const QString&, const QByteArray &, int)) );
 
 		QObject::connect(m_session, SIGNAL(pictureInfoNotify(const QString&, KUrl, int)), this, SLOT(slotGotBuddyIconInfo(const QString&, KUrl, int )));
 
@@ -377,6 +386,15 @@ void YahooAccount::initConnectionSignals( enum SignalConnectionType sct )
 		QObject::disconnect(m_session, SIGNAL(gotBuddy(const QString &, const QString &, const QString &)),
 		                    this, SLOT(slotGotBuddy(const QString &, const QString &, const QString &)));
 
+		QObject::disconnect(m_session, SIGNAL(buddyAddResult(const QString &, const QString &, bool)),
+		                    this, SLOT(slotBuddyAddResult(const QString &, const QString &, bool)));
+
+		QObject::disconnect(m_session, SIGNAL(buddyRemoveResult(const QString &, const QString &, bool)),
+		                    this, SLOT(slotBuddyRemoveResult(const QString &, const QString &, bool)));
+
+		QObject::disconnect(m_session, SIGNAL(buddyChangeGroupResult(const QString &, const QString &, bool)),
+				 this, SLOT(slotBuddyChangeGroupResult(const QString &, const QString &, bool)));
+
 		QObject::disconnect(m_session, SIGNAL(authorizationAccepted( const QString &)),
 		                 this, SLOT(slotAuthorizationAccepted( const QString &)) );
 
@@ -470,7 +488,7 @@ void YahooAccount::initConnectionSignals( enum SignalConnectionType sct )
 
 		QObject::disconnect(m_session, SIGNAL(webcamViewerRequest(const QString&)), this, SLOT(slotWebcamViewerRequest( const QString&)));
 
-		QObject::disconnect(m_session, SIGNAL(pictureDownloaded(const QString&, KTemporaryFile*, int )), this, SLOT(slotGotBuddyIcon(const QString&, KTemporaryFile*,int )));
+		QObject::disconnect(m_session, SIGNAL(pictureDownloaded(const QString&, const QByteArray &, int )), this, SLOT(slotGotBuddyIcon(const QString&, const QByteArray &,int )));
 
 		QObject::disconnect(m_session, SIGNAL(pictureInfoNotify(const QString&, KUrl, int)), this, SLOT(slotGotBuddyIconInfo(const QString&, KUrl, int )));
 
@@ -521,7 +539,7 @@ void YahooAccount::connectWithPassword( const QString &passwd )
 		return;
 	}
 
-	QString server = configGroup()->readEntry( "Server", "scs.msg.yahoo.com" );
+	QString server = configGroup()->readEntry( "Server", "scsa.msg.yahoo.com" );
 	int port = configGroup()->readEntry( "Port", 5050 );
 
 	initConnectionSignals( MakeConnections );
@@ -543,7 +561,8 @@ void YahooAccount::disconnect()
 	if ( isConnected() )
 	{
 		kDebug(YAHOO_GEN_DEBUG) <<  "Attempting to disconnect from Yahoo server ";
-
+		
+		disconnected( Manual );
 		m_session->close();
 		static_cast<YahooContact *>( myself() )->setOnlineStatus( m_protocol->Offline );
 
@@ -551,7 +570,7 @@ void YahooAccount::disconnect()
 		for ( it = contacts().constBegin(); it != itEnd; ++it )
 			static_cast<YahooContact *>( it.value() )->setOnlineStatus( m_protocol->Offline );
 
-		disconnected( Manual );
+		static_cast<YahooContact*>( myself() )->setOnlineStatus( m_protocol->Offline );
 	}
 	else
 	{       //make sure we set everybody else offline explicitly, just for cleanup
@@ -561,6 +580,8 @@ void YahooAccount::disconnect()
 		QHash<QString,Kopete::Contact*>::ConstIterator it, itEnd = contacts().constEnd();
 		for ( it = contacts().constBegin(); it != itEnd; ++it )
 			static_cast<YahooContact*>( it.value() )->setOnlineStatus( m_protocol->Offline );
+
+		static_cast<YahooContact*>( myself() )->setOnlineStatus( m_protocol->Offline );
 	}
 
 	initConnectionSignals( DeleteConnections );
@@ -622,7 +643,7 @@ void YahooAccount::fillActionMenu( KActionMenu *actionMenu )
 
 YahooContact *YahooAccount::contact( const QString &id )
 {
-	return static_cast<YahooContact *>(contacts()[id]);
+	return static_cast<YahooContact *>(contacts().value( id ));
 }
 
 bool YahooAccount::createContact(const QString &contactId, Kopete::MetaContact *parentContact )
@@ -696,6 +717,7 @@ void YahooAccount::slotLoginResponse( int succ , const QString &url )
 
 		setBuddyIcon( myself()->property( Kopete::Global::Properties::self()->photo() ).value().toString() );
 		m_session->getYABEntries( m_YABLastMerge, m_YABLastRemoteRevision );
+		IDs.clear();
 		m_lastDisconnectCode = 0;
 		theHaveContactList = true;
 		return;
@@ -804,6 +826,40 @@ void YahooAccount::slotGotBuddy( const QString &userid, const QString &alias, co
 		Kopete::Group *g=Kopete::ContactList::self()->findGroup(group);
 		addContact(userid, alias.isEmpty() ? userid : alias, g, Kopete::Account::ChangeKABC);
 	}
+
+	kDebug(YAHOO_GEN_DEBUG) << IDs;
+}
+
+void YahooAccount::slotBuddyAddResult( const QString &userid, const QString &group, bool success )
+{
+     kDebug(YAHOO_GEN_DEBUG) << success;
+
+     if(success)
+	  IDs[userid] = QPair<QString, QString>(group, QString());
+
+     kDebug(YAHOO_GEN_DEBUG) << IDs;
+}
+
+void YahooAccount::slotBuddyRemoveResult( const QString &userid, const QString &group, bool success )
+{
+     kDebug(YAHOO_GEN_DEBUG);
+
+     // Ignore success here, the only reason this will fail is because the
+     // contact isn't on the server's list, so we shouldn't have them in our
+     // list either.
+     IDs.remove(userid);
+
+     kDebug(YAHOO_GEN_DEBUG) << IDs;
+}
+
+void YahooAccount::slotBuddyChangeGroupResult(const QString &userid, const QString &group, bool success)
+{
+     kDebug(YAHOO_GEN_DEBUG);
+     
+     if(success)
+	  IDs[userid] = QPair<QString, QString>(group, QString());
+
+     kDebug(YAHOO_GEN_DEBUG) << IDs;
 }
 
 void YahooAccount::slotAuthorizationAccepted( const QString &who )
@@ -955,7 +1011,7 @@ QString YahooAccount::prepareIncomingMessage( const QString &messageText )
 		pos = regExp.indexIn( newMsgText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-			newMsgText.replace( regExp, QLatin1String("" ) );
+			newMsgText.remove( regExp );
 
 		}
 	}
@@ -965,7 +1021,7 @@ QString YahooAccount::prepareIncomingMessage( const QString &messageText )
 		pos = regExp.indexIn( newMsgText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-			newMsgText.replace( regExp, QLatin1String("" ) );
+			newMsgText.remove( regExp );
 		}
 	}
 
@@ -1098,7 +1154,7 @@ void YahooAccount::slotGotConfInvite( const QString & who, const QString & room,
 	QString m = who;
 	QStringList myMembers;
 	myMembers.push_back( who );
-	for( QStringList::const_iterator it = ++members.begin(); it != members.end(); it++ )
+	for( QStringList::const_iterator it = ++members.constBegin(); it != members.constEnd(); ++it )
 	{
 		if( *it != m_session->userId() )
 		{
@@ -1108,7 +1164,7 @@ void YahooAccount::slotGotConfInvite( const QString & who, const QString & room,
 	}
 	if( KMessageBox::Yes == KMessageBox::questionYesNo( Kopete::UI::Global::mainWidget(),
 		i18n("%1 has invited you to join a conference with %2.\n\nHis/her message: %3\n\nAccept?",
-				who, m, msg), QString(), KGuiItem( i18n("Accept") ), KGuiItem( i18n("Ignore") ) ) )
+				who, m, msg), QString(), KGuiItem( i18nc("@action","Accept") ), KGuiItem( i18nc("@action","Ignore") ) ) )
 	{
 		m_session->joinConference( room, myMembers );
 		if( !m_conferences[room] )
@@ -1119,7 +1175,7 @@ void YahooAccount::slotGotConfInvite( const QString & who, const QString & room,
 
 			QObject::connect( session, SIGNAL(leavingConference( YahooConferenceChatSession * ) ), this, SLOT( slotConfLeave( YahooConferenceChatSession * ) ) );
 
-			for ( QStringList::ConstIterator it = myMembers.begin(); it != myMembers.end(); ++it )
+			for ( QStringList::ConstIterator it = myMembers.constBegin(); it != myMembers.constEnd(); ++it )
 			{
 				YahooContact * c = contact( *it );
 				if ( !c )
@@ -1154,8 +1210,7 @@ void YahooAccount::prepareConference( const QString &who )
 	QHash<QString,Kopete::Contact*>::ConstIterator it, itEnd = contacts().constEnd();
 	for( it = contacts().constBegin(); it != itEnd; ++it )
 	{
-		if( it.value() != myself() )
-			buddies.push_back( it.value()->contactId() );
+		buddies.push_back( it.value()->contactId() );
 	}
 
 	YahooInviteListImpl *dlg = new YahooInviteListImpl( Kopete::UI::Global::mainWidget() );
@@ -1374,7 +1429,7 @@ void YahooAccount::slotModifyYABEntryError( YABEntry *entry, const QString &msg
 	YahooContact* kc = contact( entry->yahooId );
 	if( kc )
 		kc->setYABEntry( entry, true );
-	KMessageBox::sorry( Kopete::UI::Global::mainWidget(), msg, i18n( "Yahoo Plugin" ) );
+	KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Sorry, msg, i18n( "Yahoo Plugin" ) );
 }
 
 void YahooAccount::slotGotFile( const QString &  who, const QString &  url , long /* expires */, const QString &  msg , const QString &  fname, unsigned long  fesize, const QPixmap &preview )
@@ -1560,7 +1615,7 @@ void YahooAccount::slotGotWebcamInvite( const QString& who )
 	m_pendingWebcamInvites.append( who );
 
 	if( KMessageBox::Yes == KMessageBox::questionYesNo( Kopete::UI::Global::mainWidget(), i18n("%1 has invited you to view his/her webcam. Accept?", who),
-                            QString(), KGuiItem( i18n("Accept") ), KGuiItem( i18n("Ignore") ) ) )
+                            QString(), KGuiItem( i18nc("@action","Accept") ), KGuiItem( i18nc("@action","Ignore") ) ) )
 	{
 		m_pendingWebcamInvites.removeAll( who );
 		m_session->requestWebcam( who );
@@ -1568,7 +1623,7 @@ void YahooAccount::slotGotWebcamInvite( const QString& who )
 }
 void YahooAccount::slotWebcamNotAvailable( const QString &who )
 {
-	KMessageBox::sorry( Kopete::UI::Global::mainWidget(), i18n("Webcam for %1 is not available.", who), i18n( "Yahoo Plugin" ) );
+	KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Sorry, i18n("Webcam for %1 is not available.", who), i18n( "Yahoo Plugin" ) );
 }
 
 void YahooAccount::slotGotWebcamImage( const QString& who, const QPixmap& image )
@@ -1627,7 +1682,7 @@ void YahooAccount::slotGotBuddyIconInfo(const QString &who, KUrl url, int checks
 		m_session->downloadPicture( who, url, checksum );
 }
 
-void YahooAccount::slotGotBuddyIcon( const QString &who, KTemporaryFile *file, int checksum )
+void YahooAccount::slotGotBuddyIcon( const QString &who, const QByteArray &data, int checksum )
 {
 	kDebug(YAHOO_GEN_DEBUG) ;
 	YahooContact *kc = contact( who );
@@ -1635,7 +1690,7 @@ void YahooAccount::slotGotBuddyIcon( const QString &who, KTemporaryFile *file, i
 		kDebug(YAHOO_GEN_DEBUG) << "contact " << who << " doesn't exist.";
 		return;
 	}
-	kc->setDisplayPicture( file, checksum );
+	kc->setDisplayPicture( data, checksum );
 }
 void YahooAccount::slotGotBuddyIconRequest( const QString & who )
 {
@@ -1666,7 +1721,7 @@ void YahooAccount::setBuddyIcon( const KUrl &url )
 		uint expire = myself()->property( YahooProtocol::protocol()->iconExpire ).value().toInt();
 
 		if ( image.isNull() ) {
-			KMessageBox::sorry( Kopete::UI::Global::mainWidget(), i18n( "<qt>The selected buddy icon could not be opened. <br />Please set a new buddy icon.</qt>" ), i18n( "Yahoo Plugin" ) );
+			KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Sorry, i18n( "<qt>The selected buddy icon could not be opened. <br />Please set a new buddy icon.</qt>" ), i18n( "Yahoo Plugin" ) );
 			return;
 		}
 		image = image.scaled( 96, 96, Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation );
@@ -1681,7 +1736,7 @@ void YahooAccount::setBuddyIcon( const KUrl &url )
 
 		if( !image.save( newlocation, "PNG" ) || !iconFile.open(QIODevice::ReadOnly) )
 		{
-			KMessageBox::sorry( Kopete::UI::Global::mainWidget(), i18n( "An error occurred when trying to change the display picture." ), i18n( "Yahoo Plugin" ) );
+			KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Sorry, i18n( "An error occurred when trying to change the display picture." ), i18n( "Yahoo Plugin" ) );
 			return;
 		}
 
@@ -1771,7 +1826,7 @@ void YahooAccount::slotWebcamViewerJoined( const QString &viewer )
 void YahooAccount::slotWebcamViewerRequest( const QString &viewer )
 {
 	if( KMessageBox::Yes == KMessageBox::questionYesNo( Kopete::UI::Global::mainWidget(), i18n("%1 wants to view your webcam. Grant access?",
-		viewer), QString(), KGuiItem( i18n("Accept") ), KGuiItem( i18n("Ignore") ) ) )
+		viewer), QString(), KGuiItem( i18nc("@action","Accept") ), KGuiItem( i18nc("@action","Ignore") ) ) )
 		m_session->grantWebcamAccess( viewer );
 }
 
@@ -1803,7 +1858,7 @@ void YahooAccount::slotWebcamPaused( const QString &who )
 	kc->webcamPaused();
 }
 
-void YahooAccount::setOnlineStatus( const Kopete::OnlineStatus& status , const Kopete::StatusMessage &reason)
+void YahooAccount::setOnlineStatus( const Kopete::OnlineStatus& status, const Kopete::StatusMessage &reason, const OnlineStatusOptions& options )
 {
 	kDebug(YAHOO_GEN_DEBUG) ;
 	if ( myself()->onlineStatus().status() == Kopete::OnlineStatus::Offline &&
